@@ -23,7 +23,7 @@
  */
 
 #ifndef lint
-static  char sccsid[] = "@(#)send.c	2.26 6/21/93 (C) 1988 University of Oulu, \
+static  char sccsid[] = "@(#)send.c	2.27 02 Sep 1993 (C) 1988 University of Oulu, \
 Computing Center and Jarkko Oikarinen";
 #endif
 
@@ -270,9 +270,11 @@ va_dcl
 	va_list	vl;
 #endif
 
+/*
 # ifdef NPATH
         check_command((long)1, pattern, p1, p2, p3);
 # endif
+*/
 
 #ifdef VMS
 	extern int goodbye;
@@ -462,8 +464,7 @@ va_dcl
 		    user == cptr || !user->user)
 			continue;
 		for (lp = user->user->channel; lp; lp = lp->next)
-			if (IsMember(user, lp->value.chptr) &&
-			    IsMember(cptr, lp->value.chptr))
+			if (IsMember(cptr, lp->value.chptr))
 			    {
 # ifdef	USE_VARARGS
 				sendto_prefix_one(cptr, user, pattern, vl);
